#!/usr/bin/env python
# -*- coding: utf-8 -*-


import os
import sys

from paver.easy import task, path
from paver.deps.six import exec_


try:
    import sett  # noqa
except ImportError:
    sys.path.append(os.path.dirname(__file__))

from sett import ROOT


def find_version(filename):
    filepath = os.path.join(os.path.dirname(__file__), filename)
    with open(filepath, 'rt') as init:
        for line in init:
            if line.startswith('__version__'):
                x, version = line.split('=', 1)
                return version.strip().strip('\'"')
        else:
            raise ValueError('Cannot find the version in {0}'.format(filename))


def parse_requirements(requirements_txt):
    requirements = []
    try:
        with open(requirements_txt, 'rt') as f:
            for line in f:
                line = line.strip()
                if line.startswith('#') or not line:
                    continue
                if line.startswith('-'):
                    raise ValueError('Unexpected command {0} in {1}'.format(
                        line,
                        requirements_txt,
                    ))

                requirements.append(line)
        return requirements
    except IOError:
        return []


@task
def setup_options():
    from paver.setuputils import setup
    import setuptools

    setup(
        name='sett',
        version=find_version('sett/__init__.py'),
        packages=setuptools.find_packages(
            exclude=[
                'tests',
                'tests.*',
            ]
        ),
        url='https://github.org/cecedille1/sett',
        author=u'Grégoire ROCHER',
        author_email='gr@enix.org',
        install_requires=parse_requirements('requirements.txt'),
        include_package_data=True,
    )


if path(sys.argv[0]).realpath() == path(__file__).dirname().joinpath('setup.py').realpath():
    setup_options()

try:
    with open(ROOT.joinpath('localpavement.py'), 'r') as localpavement:
        exec_(localpavement.read(), locals(), globals())
except (IOError, ImportError) as e:
    pass
